resolve_cur

Function resolve_cur 

pub fn resolve_cur(
    pane: &str,
    panes: &[(String, String)],
    pane_cmd: &str,
) -> String
The pane the picker was opened from, resolved through an ssh window.

If that pane is a window onto another host, the row you are on is over THERE, not the ssh pane you are looking through.